@@ -125,7 +125,7 @@ enum {
 #define GDM_KEY_AUTOMATICLOGIN_ENABLE "daemon/AutomaticLoginEnable=true"
 #define GDM_KEY_AUTOMATICLOGIN "daemon/AutomaticLogin="
 #define GDM_KEY_LOCALNOPASSWORDUSERS "daemon/LocalNoPasswordUsers="
-#define GDM_KEY_ALWAYSRESTARTSERVER "daemon/AlwaysRestartServer=false"
+#define GDM_KEY_ALWAYSRESTARTSERVER "daemon/AlwaysRestartServer=true"
 #define GDM_KEY_GREETER "daemon/Greeter=" EXPANDED_BINDIR "/gdmlogin"
 #define GDM_KEY_REMOTEGREETER "daemon/RemoteGreeter=" EXPANDED_BINDIR "/gdmlogin"
 #define GDM_KEY_GROUP "daemon/Group=gdm"
@@ -161,6 +161,10 @@ enum {
 #define GDM_KEY_STANDARD_XSERVER "daemon/StandardXServer=/usr/X11R6/bin/X"
 #define GDM_KEY_FLEXIBLE_XSERVERS "daemon/FlexibleXServers=5"
 #define GDM_KEY_XNEST "daemon/Xnest=/usr/X11R6/bin/Xnest -name Xnest"
+/* Keys for automatic VT allocation rather then letting it up to the
+ * X server */
+#define GDM_KEY_FIRSTVT "daemon/FirstVT=7"
+#define GDM_KEY_VTALLOCATION "daemon/VTAllocation=true"
 
 /* Per server definitions */
 #define GDM_KEY_SERVER_NAME "name=Standard server"
@@ -202,7 +206,6 @@ enum {
 #define GDM_KEY_FACE "greeter/DefaultFace=" EXPANDED_PIXMAPDIR "nobody.png"
 #define GDM_KEY_FACEDIR "greeter/GlobalFaceDir=" EXPANDED_DATADIR "/faces/"
 #define GDM_KEY_ICON "greeter/Icon=" EXPANDED_PIXMAPDIR "/gdm.png"
-#define GDM_KEY_LOCALE "greeter/DefaultLocale=english"
 #define GDM_KEY_LOCFILE "greeter/LocaleFile=" EXPANDED_LOCALEDIR "/locale.alias"
 #define GDM_KEY_LOGO "greeter/Logo=" EXPANDED_PIXMAPDIR "/gdm-foot-logo.png"
 #define GDM_KEY_QUIVER "greeter/Quiver=true"
@@ -292,9 +295,7 @@ struct _GdmDisplay {
 
     gboolean handled;
 
-#ifdef __linux__
     int vt;
-#endif
 
     gboolean busy_display;
 
