@@ -1,5 +1,5 @@
 /*
- *    GDMphotosetup - graphical .gnome/photo setup program for users
+ *    GDMphotosetup - graphical .gnome2/photo setup program for users
  *    (c)2001 Queen of England
  *    
  *    This program is free software; you can redistribute it and/or modify
@@ -30,6 +30,67 @@
 
 #include "gdm.h"
 
+int response = -999;
+
+static gboolean
+gdm_check (void)
+{
+	GtkWidget *dialog;
+	FILE *fp = NULL;
+	long pid;
+	char *pidfile;
+
+	pidfile = ve_config_get_string (ve_config_get (GDM_CONFIG_FILE),
+					GDM_KEY_PIDFILE);
+
+	pid = 0;
+	if (pidfile != NULL)
+		fp = fopen (pidfile, "r");
+	if (fp != NULL) {
+		fscanf (fp, "%ld", &pid);
+		fclose (fp);
+	}
+
+	g_free (pidfile);
+
+	errno = 0;
+	if (pid <= 1 ||
+	    (kill (pid, 0) < 0 &&
+	     errno != EPERM)) {
+		dialog = gtk_message_dialog_new
+			(NULL /* parent */,
+			 GTK_DIALOG_MODAL /* flags */,
+			 GTK_MESSAGE_WARNING,
+			 GTK_BUTTONS_OK,
+			 "foo");
+		 gtk_label_set_markup
+			 (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label),
+			  _("<b>GDM (The GNOME Display Manager) "
+			    "is not running.</b>\n\n"
+			    "You might in fact be using a different "
+			    "display manager, such as KDM "
+			    "(KDE Display Manager or xdm).\n"
+			    "If you still wish to use this feature, "
+			    "either start GDM your self or ask your "
+			    "system administrator to start GDM."));
+		gtk_widget_show_all (dialog);
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+
+
+static void
+dialog_response (GtkWidget *dialog, int res, gpointer data)
+{
+	response = res;
+	gtk_main_quit ();
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -55,6 +116,10 @@ main (int argc, char *argv[])
 	max_size = gnome_config_get_int (GDM_KEY_MAXFILE);
 	gnome_config_pop_prefix ();
 
+	if ( ! gdm_check ()) {
+		return 1;
+	}
+
 	if ( ! face_browser) {
 		GtkWidget *d;
 		d = gtk_message_dialog_new (NULL /* parent */,
@@ -90,16 +155,26 @@ main (int argc, char *argv[])
 			    photo, TRUE, TRUE, 0);
 
 	if ( ! ve_string_empty (last_pix)) {
-		GtkWidget *e = gnome_pixmap_entry_gtk_entry
-			(GNOME_PIXMAP_ENTRY (photo));
-		gtk_entry_set_text (GTK_ENTRY (e), last_pix);
+		gnome_file_entry_set_filename (GNOME_FILE_ENTRY (photo),
+					       last_pix);
 	}
 
 	gtk_widget_show_all (dialog);
 
-	while (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
+	g_signal_connect (G_OBJECT (dialog), "response",
+			  G_CALLBACK (dialog_response),
+			  NULL);
+
+	for (;;) {
 		struct stat s;
-		char *pixmap = gnome_pixmap_entry_get_filename (GNOME_PIXMAP_ENTRY (photo));
+		char *pixmap;
+
+		gtk_main ();
+
+		if (response != GTK_RESPONSE_OK)
+			break;
+
+		pixmap = gnome_pixmap_entry_get_filename (GNOME_PIXMAP_ENTRY (photo));
 		if (ve_string_empty (pixmap) ||
 		    stat (pixmap, &s) < 0) {
 			GtkWidget *d;
@@ -128,10 +203,10 @@ main (int argc, char *argv[])
 			char buf[4096];
 			size_t size;
 			char *photofile = g_strconcat (g_get_home_dir (),
-						       "/.gnome/photo",
+						       "/.gnome2/photo",
 						       NULL);
 			char *cfg_file = g_strconcat (g_get_home_dir (),
-						      "/.gnome/gdm",
+						      "/.gnome2/gdm",
 						      NULL);
 			int fddest, fdsrc;
 
