@@ -276,17 +276,25 @@ greeter_session_init (void)
 	lstat (s, &statbuf);
 
 	/* If default session link exists, find out what it points to */
-	if (S_ISLNK (statbuf.st_mode) &&
-	    g_ascii_strcasecmp (dent->d_name, "default") == 0)
+	if (S_ISLNK (statbuf.st_mode))
 	  {
-	    gchar t[_POSIX_PATH_MAX];
-	    
-	    linklen = readlink (s, t, _POSIX_PATH_MAX);
-	    t[linklen] = 0;
-	    g_free (default_session);
-	    default_session = g_strdup (t);
-	    
-	    got_default_link = TRUE;
+	    if (g_ascii_strcasecmp (dent->d_name, "default") == 0)
+	      {
+	        gchar t[_POSIX_PATH_MAX];
+	        
+	        linklen = readlink (s, t, _POSIX_PATH_MAX);
+	        t[linklen] = 0;
+	        g_free (default_session);
+	        default_session = g_strdup (t);
+	        
+	        got_default_link = TRUE;
+	      }
+	    else
+	      {
+		/* This may just be a link to somewhere so
+		 * stat the file itself */
+		stat (s, &statbuf);
+	      }
 	  }
 
 	/* If session script is readable/executable add it to the list */
