@@ -22,6 +22,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <locale.h>
 #include <libgnome/libgnome.h>
 
 #include "ve-misc.h"
@@ -367,3 +368,17 @@ ve_waitpid_no_signal (pid_t pid, int *status, int options)
 			return ret;
 	}
 }
+
+gboolean
+ve_locale_exists (const char *loc)
+{
+	gboolean ret;
+	char *old = g_strdup (setlocale (LC_ALL, NULL));
+	if (setlocale (LC_MESSAGES, loc) != NULL)
+		ret = TRUE;
+	else
+		ret = FALSE;
+	setlocale (LC_MESSAGES, old);
+	g_free (old);
+	return ret;
+}
