@@ -28,10 +28,16 @@
 
 char **	ve_split (const char *s);
 char *	ve_first_word (const char *s);
+gboolean ve_first_word_executable (const char *s,
+				   gboolean only_existance);
 char *  ve_rest (const char *s);
 char **	ve_vector_merge (char * const *v1, char * const *v2);
 int	ve_vector_len (char * const *v);
 
+/* Gets the first existing command out of a list separated by semicolons */
+char *	ve_get_first_working_command (const char *list,
+				      gboolean only_existance);
+
 gboolean ve_bool_equal (gboolean a, gboolean b);
 
 gboolean ve_is_string_in_list (const GList *list,
@@ -66,6 +72,7 @@ char * ve_strftime (struct tm *the_tm, const char *format);
 /* function which doesn't stop on signals */
 pid_t ve_waitpid_no_signal (pid_t pid, int *status, int options);
 
-
+/* Testing for existance of a certain locale */
+gboolean ve_locale_exists (const char *loc);
 
 #endif /* VE_MISC_H */
